@@ -531,22 +531,22 @@ class DjangoWithExtraContextAdmin(admin.ModelAdmin):
         return {}
 
     def get_changeform_view_extra_context(self, request, object_id=None, form_url='', extra_context=None):
-        return self.get_extra_context(request, object_id, form_url, extra_context)
+        return self.get_extra_context(request, object_id=object_id, form_url=form_url, extra_context=extra_context)
     
     def get_changelist_view_extra_context(self, request, extra_context=None):
-        return self.get_extra_context(request, extra_context)
+        return self.get_extra_context(request, extra_context=extra_context)
     
     def get_delete_view_extra_context(self, request, object_id, extra_context=None):
-        return self.get_extra_context(request, object_id, extra_context)
+        return self.get_extra_context(request, object_id=object_id, extra_context=extra_context)
 
     def get_history_view_extra_context(self, request, object_id, extra_context=None):
-        return self.get_extra_context(request, object_id, extra_context)
+        return self.get_extra_context(request, object_id=object_id, extra_context=extra_context)
 
     def get_add_view_extra_context(self, request, form_url, extra_context=None):
-        return self.get_extra_context(request, form_url, extra_context)
+        return self.get_extra_context(request, form_url=form_url, extra_context=extra_context)
 
     def get_change_view_extra_context(self, request, object_id, form_url='', extra_context=None):
-        return self.get_extra_context(request, object_id, form_url, extra_context)
+        return self.get_extra_context(request, object_id=object_id, form_url=form_url, extra_context=extra_context)
 
     @csrf_protect_m
     def changeform_view(self, request, object_id=None, form_url='', extra_context=None):
